import clsx from "clsx";
import { Viewport } from "next";
import { NextIntlClientProvider } from "next-intl";
import { getMessages } from "next-intl/server";
import { Inter as FontSans } from "next/font/google";
import { ReactNode } from "react";
import "../globals.css";

import PageTransitionEffect from "@/components/PageTransitionEffect";
import { Providers } from "./providers";

// 加载字体
const fontSans = FontSans({
    subsets: ["latin"],
    variable: "--font-sans",
});
export const viewport: Viewport = {
    themeColor: [
        { media: "(prefers-color-scheme: light)", color: "white" },
        { media: "(prefers-color-scheme: dark)", color: "black" },
    ],
};
export default async function LocaleLayout({
    children,
    params: { locale },
}: {
    children: ReactNode;
    params: { locale: string };
}) {
    const messages = await getMessages();
    return (
        <html lang={locale} suppressHydrationWarning>
            <body className={clsx("bg-amber-50 font-sans", fontSans.variable)}>
                <Providers themeProps={{ defaultTheme: "dark", attribute: "class" }}>
                    <NextIntlClientProvider messages={messages}>
                        <PageTransitionEffect>{children}</PageTransitionEffect>
                    </NextIntlClientProvider>
                </Providers>
            </body>
        </html>
    );
}
