import { Link } from "@/i18n";
import clsx from "clsx";
import { useTranslations } from "next-intl";
import { FC, PropsWithChildren, ReactNode } from "react";
import HeaderTitle from "./HerderTitle";
import styles from "./style.module.scss";
/**
 * @description HeaderProps
 * @param {boolean} headerPlaceholder 是否展示展位元素
 * @param {() => ReactNode} headerRender 自定义渲染
 */
export interface HeaderProps {
    headerPlaceholder?: boolean;
    headerRender?: () => ReactNode;
}

const cs = clsx(["iconfont icon-gengduo", styles.menu]);
const DefaultHeader: FC = () => {
    const t = useTranslations("Header");
    return (
        <div className={styles.headerMain}>
            <div className={styles.headerLeft}>
                <div className={cs}></div>
            </div>
            <HeaderTitle />
            <div className={styles.headerRight}>
                <div className={styles.right}>
                    <Link href={"/login"}>{t("login")}</Link>
                    <Link href={"/login"} className={styles.rightActive}>
                        {t("register")}
                    </Link>
                </div>
            </div>
        </div>
    );
};

const Header: FC<PropsWithChildren<HeaderProps>> = (props) => {
    const { headerPlaceholder = true, headerRender } = props;
    const cs = clsx({
        [styles.placeholder]: headerPlaceholder,
    });
    return (
        <div className={cs}>
            <div className={styles.headerWrap}>
                {headerRender ? headerRender() : <DefaultHeader />}
            </div>
        </div>
    );
};

export default Header;
